package utils

import (
	"fmt"
	beeLogger "github.com/beego/bee/v2/logger"
	"github.com/beego/beego/v2/server/web"
	"github.com/rdlucklib/rdluck_tools/cache"
)

var (
	RunMode        string //运行模式
	MYSQL_URL             string //数据库连接

	REDIS_CACHE string       //缓存地址
	Rc          *cache.Cache //redis缓存
	Re          error        //redis错误
)

//微信配置信息
var (
	WxId                string //微信原始ID
	WxAppId             string
	WxAppSecret         string
	TemplateIdByProduct string //产品运行报告通知-模板ID

	TemplateRedirectUrl                   string //模板消息跳转地址
	DayReportTemplateRedirectUrl          string //模板消息跳转地址（晨报、周报）
	TemplateIdByCompanyApply              string //客户申请单审批通知-模板ID
	TemplateCompanyApplyRedirectUrl       string //审批单模板消息跳转地址
	TemplateIdByCompanyReceive            string //销售跨部门领取客户通知-模板ID
	TemplateIdByCompanyReceivePermission  string //销售"添加客户/领取客户"权限变更通知
	WxMsgTemplateIdActivityChangeApply    string //查研观向活动变更通知-模板ID
	WxMsgTemplateIdActivityChangeApplyXzs string //查研观向活动变更通知-模板ID（小助手）
	TemplateIdByProductXzs                string //产品运行报告通知-模板ID(小助手)
	WxCygxAppId                           string //查研观向小程序APPID
	WxMsgTemplateIdAskByUser              string //查研观向用户提问新消息推送ID
	WxCrmAppId                            string //随手办公小程序APPID
	WxPublicIdXzs                         string //查研观向小助手公众号
	WxPublicSecretXzs                     string //查研观向小助手公众号
	WxYbAppId                             string //弘则研报小程序APPID

	WxMsgTemplateIdWithRoadshowPending      string //路演->研究员收到待处理的申请
	WxMsgTemplateIdWithRoadshowDetailResult string //路演->销售收到处理结果
	WxMsgTemplateIdWithRoadshowDeleteNotice string //路演->研究员收到活动删除通知

	WxMsgTemplateIdWithYbCommunityQuestion string // 研报小程序->问答社区回复通知
)

func init() {
	tmpRunMode, err := web.AppConfig.String("run_mode")
	if err != nil {
		panic("配置文件读取run_mode错误 " + err.Error())
	}
	RunMode = tmpRunMode

	if RunMode == "" {
		localIp, err := GetLocalIP()
		fmt.Println("localIp:", localIp)
		if localIp == "10.0.0.123" {
			RunMode = "debug"
		} else {
			RunMode = "release"
		}
		fmt.Println("RunMode:", RunMode)
		configPath := `/home/code/config/hongze_public_api/conf/app.conf`
		fmt.Println("configPath:", configPath)
		err = web.LoadAppConfig("ini", configPath)
		if err != nil {
			fmt.Println("web.LoadAppConfig Err:" + err.Error())
		}

		WxRelease()
	}

	config, err := web.AppConfig.GetSection(RunMode)
	if err != nil {
		panic("配置文件读取错误 " + err.Error())
	}
	MYSQL_URL = config["mysql_url"]

	REDIS_CACHE = config["beego_cache"]
	if len(REDIS_CACHE) <= 0 {
		panic("redis链接参数没有配置")
	}
	Rc, Re = cache.NewCache(REDIS_CACHE) //初始化缓存
	if Re != nil {
		fmt.Println(Re)
		panic(Re)
	}

	beeLogger.Log.Info(RunMode + " 模式")
	if RunMode == "release" {

	} else {
		WxDebug()
	}
}


//测试环境模板消息
func WxDebug() {
	WxAppId = "wx9b5d7291e581233a"
	WxAppSecret = "f4d52e34021eee262dce9682b31f8861"
	WxId = "gh_5dc508325c6f"
	//模板消息
	{
		TemplateIdByProduct = "-YjuPOB7Fqd-S3ilabYa6wvjDY9aXmeEfPN6DCiy-EY"
		WxMsgTemplateIdAskByUser = `qfNuops-sKrfIkbA7U97A7gSrX03mUpoEpJksRUdloo`
		TemplateIdByCompanyApply = "eTalI1LbiT_B0mTaBeDTlfSMITenK8dQIgEB5yqjjvA"
		//销售跨部门领取客户通知
		TemplateIdByCompanyReceive = "KAxFvX79f-DHmtC_Jw98elvqxiDPK0xP_b48LUT-Y14"
		//销售"添加客户/领取客户"权限变更通知
		TemplateIdByCompanyReceivePermission = "CB7bOl7f3viMG4s1uhRo7WM0Jbx3WvodKuIZ8A_z8fM"
		WxMsgTemplateIdActivityChangeApply = "CB7bOl7f3viMG4s1uhRo7WM0Jbx3WvodKuIZ8A_z8fM"

		//路演
		WxMsgTemplateIdWithRoadshowPending = "qfNuops-sKrfIkbA7U97A7gSrX03mUpoEpJksRUdloo"      //路演->研究员收到待处理的申请
		WxMsgTemplateIdWithRoadshowDetailResult = "CB7bOl7f3viMG4s1uhRo7WM0Jbx3WvodKuIZ8A_z8fM" //路演->销售收到处理结果
		WxMsgTemplateIdWithRoadshowDeleteNotice = "CB7bOl7f3viMG4s1uhRo7WM0Jbx3WvodKuIZ8A_z8fM" //路演->研究员收到活动删除通知

		// 研报小程序
		WxMsgTemplateIdWithYbCommunityQuestion = "CB7bOl7f3viMG4s1uhRo7WM0Jbx3WvodKuIZ8A_z8fM" // 研报小程序->问答社区回复通知
	}

	//查研观向小助手
	{
		//原有的模板ID
		WxPublicIdXzs = "wx9b5d7291e581233a"                                                  //查研观向小助手
		WxPublicSecretXzs = "f4d52e34021eee262dce9682b31f8861"                                //查研观向小助手
		WxMsgTemplateIdActivityChangeApplyXzs = "CB7bOl7f3viMG4s1uhRo7WM0Jbx3WvodKuIZ8A_z8fM" //查研观向活动变更通知-模板ID（小助手）
		TemplateIdByProductXzs = "-YjuPOB7Fqd-S3ilabYa6wvjDY9aXmeEfPN6DCiy-EY"                //产品运行报告通知-模板ID(小助手)
	}

}

//生产环境模板消息
func WxRelease() {
	WxAppId = "wx4a844c734d8c8e56"
	WxAppSecret = "26c586e7ccb3c575433f0f37797b3eeb"
	WxId = "gh_b67e0049fb8c"
	//模板消息
	{
		TemplateIdByProduct = "Cp2wF8gvBtxyWV4DeYuI172oqwyYXVRSm3AyJO42d84"
		TemplateIdByCompanyApply = "ZKcOfNIWBpwHJxpptufHIK1mp2nIwkT3cxub-35cFqI"
		WxMsgTemplateIdActivityChangeApply = "dYg6iHooRq74PyCXmw_Ns7qdJZmbtLoKS2p2FKeaXl0"
		//销售跨部门领取客户通知
		TemplateIdByCompanyReceive = "A5fV-XWBcu-LIj_W-tBiOJ-D39a9WDd9GOB0WGbpoBg"
		//销售"添加客户/领取客户"权限变更通知
		TemplateIdByCompanyReceivePermission = "dYg6iHooRq74PyCXmw_Ns7qdJZmbtLoKS2p2FKeaXl0"
		//路演
		WxMsgTemplateIdWithRoadshowPending = "PaoDanHGlt1kFw5q-4_ipJSwO3FyZpxSSNg4rwB7YCk"      //路演->研究员收到待处理的申请
		WxMsgTemplateIdWithRoadshowDetailResult = "dYg6iHooRq74PyCXmw_Ns7qdJZmbtLoKS2p2FKeaXl0" //路演->销售收到处理结果
		WxMsgTemplateIdWithRoadshowDeleteNotice = "dYg6iHooRq74PyCXmw_Ns7qdJZmbtLoKS2p2FKeaXl0" //路演->研究员收到活动删除通知

		// 研报小程序
		WxMsgTemplateIdWithYbCommunityQuestion = "dYg6iHooRq74PyCXmw_Ns7qdJZmbtLoKS2p2FKeaXl0" // 研报小程序->问答社区回复通知
	}

	//查研观向小助手
	{
		//新的模板ID
		WxPublicIdXzs = "wxb7cb8a15abad5b8e"                                                  //查研观向小助手
		WxPublicSecretXzs = "f425ba2863084249722af1e2a5cfffd3"                                //查研观向小助手
		WxMsgTemplateIdActivityChangeApplyXzs = "7qe3i4MrGxAIPhJeMgoqqw6j0A_foUB65DLSmxKe05s" //查研观向活动变更通知-模板ID（小助手）
		TemplateIdByProductXzs = "tNcCUiK_uUkuxaFF7M9NP2RwLkw8uHFjG-TDIxGUKxo"                //产品运行报告通知-模板ID(小助手)
	}
}